-- ScreenGallery pagelist -- all the heavy lifting goes here
-- state varables
local pageIndex = 1
local prevIndex = 1

if getenv("GalleryPage") then
	local idx = tonumber(getenv("GalleryPage"))
	pageIndex = idx
	prevIndex = idx
else -- default me, captain
	setenv("GalleryPage",1)
end

local cursorZoomY = 0.7

local numPages = 19
local function MakePageItem(pageNum)
	local firstItem = 1 + ((pageNum-1)*12)
	local endItem = pageNum * 12
	return Def.ActorFrame{
		Name="Item"..pageNum;
		-- was _2070polyester round 24px,diffuse,color("#4AFF4A");strokecolor,color("#00096B");zoom,14/24
		LoadFont("_gallery text")..{
			Name="Label";
			Text=string.format("PAGE %2i<%3i-%3i>",pageNum,firstItem,endItem);
			InitCommand=cmd(halign,0;);
		};
		LoadActor("_selector")..{
			InitCommand=cmd(x,130);
			BeginCommand=function(self)
				if getenv("GalleryPage") then
					self:zoomy(pageNum == tonumber(getenv("GalleryPage")) and cursorZoomY or 0)
				else
					self:zoomy(pageNum == 1 and cursorZoomY or 0)
				end
			end;
			-- up/down movement:
			GainFocusCommand=cmd(linear,0.2;zoomy,cursorZoomY);
			LoseFocusCommand=cmd(linear,0.2;zoomy,0);

			-- left/right movement:
			-- upon switching columns, the cursor slides over horizontally.
			-- step 1) make the LoseFocus cursor slide over to the position.
			-- step 2) un-hide GainFocus cursor and hide LoseFocus cursor.
			GainFocusLeftCommand=cmd(sleep,0.2;zoomy,cursorZoomY);
			GainFocusRightCommand=cmd(sleep,0.2;zoomy,cursorZoomY);
			LoseFocusLeftCommand=cmd(finishtweening;linear,0.2;addx,-288;sleep,0.01;zoomy,0;addx,288);
			LoseFocusRightCommand=cmd(finishtweening;linear,0.2;addx,288;sleep,0.01;zoomy,0;addx,-288);

			ScrollerMovementMessageCommand=function(self,param)
				if param.Direction == "Left" or param.Direction == "Right" then
					-- going left/right on 10 keeps you on 10; still makes noise.
					if pageNum == 10 and pageIndex == 10 then
						self:zoomy(0.25)
						self:playcommand("GainFocus")
						return
					end

					if pageIndex == pageNum then
						if param.Direction == "Left" then
							self:playcommand("GainFocusLeft")
						elseif param.Direction == "Right" then
							self:playcommand("GainFocusRight")
						end
					elseif prevIndex == pageNum then
						if param.Direction == "Left" then
							if prevIndex < 11 then -- wrapping
								self:playcommand("LoseFocusRight")
							else
								self:playcommand("LoseFocusLeft")
							end
						elseif param.Direction == "Right" then
							if prevIndex > 10 then -- wrapping
								self:playcommand("LoseFocusLeft")
							else
								self:playcommand("LoseFocusRight")
							end
						end
					end
				else
					if pageIndex == pageNum then self:playcommand("GainFocus")
					elseif prevIndex == pageNum then self:playcommand("LoseFocus")
					end
				end
			end;
		};
		LoadActor(THEME:GetPathB("ScreenGalleryPage","overlay/_new"))..{
			InitCommand=cmd(y,-1;zoom,0.75;pulse;effectperiod,0.25;effectmagnitude,1,0.8,1);
			BeginCommand=function(self)
				-- left side
				if pageNum < 11 then self:x(-22)
				-- right side
				else self:x(286)
				end
				self:visible(math.random(0,1)<0.5)
			end;
		};
	};
end

local galleryPages = {}
for i=1,numPages do
	galleryPages[i] = MakePageItem(i)
end

local t = Def.ActorFrame{
	-- handle inputs
	MenuInputMessageCommand=function(self,param)
		prevIndex = pageIndex
		if param.Input == "Up" then
			if pageIndex == 1 then
				pageIndex = 10
			elseif pageIndex == 11 then
				pageIndex = 19
			else
				pageIndex = pageIndex - 1
			end
		elseif param.Input == "Down" then
			if pageIndex == 10 then
				pageIndex = 1
			elseif pageIndex == 19 then
				pageIndex = 11
			else
				pageIndex = pageIndex + 1
			end
		elseif param.Input == "Left" then
			if pageIndex ~= 10 then
				if pageIndex > 10 then
					pageIndex = pageIndex - 10
				else
					pageIndex = pageIndex + 10
				end
			--[[
			else
				pageIndex = 19
			--]]
			end
		elseif param.Input == "Right" then
			if pageIndex ~= 10 then
				if pageIndex < 10 then
					pageIndex = pageIndex + 10
				else
					pageIndex = pageIndex - 10
				end
			--[[
			else
				pageIndex = 19
			--]]
			end
		end
		MESSAGEMAN:Broadcast("ScrollerMovement",{Direction = param.Input})
		setenv("GalleryPage",pageIndex)
	end;
	MenuUpP1MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_1, Input = "Up", }); end;
	MenuUpP2MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_2, Input = "Up", }); end;
	MenuDownP1MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_1, Input = "Down", }); end;
	MenuDownP2MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_2, Input = "Down", }); end;
	MenuLeftP1MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_1, Input = "Left", }); end;
	MenuLeftP2MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_2, Input = "Left", }); end;
	MenuRightP1MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_1, Input = "Right", }); end;
	MenuRightP2MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_2, Input = "Right", }); end;

	-- actorscroller
	Def.ActorScroller{
		InitCommand=cmd(x,SCREEN_CENTER_X-276;y,SCREEN_CENTER_Y-126);
		children = galleryPages;
		SecondsPerItem=0;
		NumItemsToDraw=numPages*2;
		TransformFunction=function(self, offset, itemIndex, numItems)
			-- split items after 10 into another column
			local xOffset = 0
			if itemIndex > 9 then
				xOffset = 288
			end
			self:x(xOffset)
			if itemIndex < 10 then
				self:y(itemIndex*20)
			else
				self:y((itemIndex - 10) * 20)
			end
		end
	};
};

return t;