-- ScreenGalleryPage images - image scroller
-- state variables
local selIndex = 1
local prevIndex = 1

local pageNum = 0
if getenv("GalleryPage") then
	pageNum = tonumber(getenv("GalleryPage"))
else
	-- fallback behavior
	pageNum = 1
	setenv("GalleryPage",1)
end

-- todo: handle this the "proper" way
local imageStart = 1 + ((pageNum-1)*12)

local numImages = 12
local function MakeImageItem(imgNum)
	local firstItem = 1 + ((imgNum)*12)
	local endItem = imgNum * 12
	local showThumb = (math.random(0,1) > 0.5)
	local fakeSelected = showThumb and (math.random(0,1) > 0.25)

	return Def.ActorFrame{
		Name="Item"..imgNum;
		LoadActor("_frame normal")..{
			Name="FrameNormal";
			InitCommand=cmd();
			BeginCommand=function(self)
				self:visible(imgNum ~= 1)
			end;
			GainFocusCommand=cmd(visible,false);
			LoseFocusCommand=cmd(visible,true);
			ChangedItemMessageCommand=function(self,param)
				if param.OldIndex == imgNum then
					self:playcommand("LoseFocus")
				end
			end;
		};
		LoadActor("_frame focused")..{
			Name="FrameFocus";
			InitCommand=cmd();
			BeginCommand=function(self)
				self:visible(imgNum == 1)
			end;
			GainFocusCommand=cmd(visible,true);
			LoseFocusCommand=cmd(visible,false);
			ChangedItemMessageCommand=function(self,param)
				if param.NewIndex == imgNum then
					self:playcommand("GainFocus")
				elseif param.OldIndex == imgNum then
					self:playcommand("LoseFocus")
				end
			end;
		};
		Def.Sprite{
			Name="Thumbnail";
			InitCommand=cmd(x,8;y,-2;);
			BeginCommand=function(self)
				if showThumb then
					self:Load(THEME:GetPathG("",string.format("_gallery/thumb/%03i",imageStart+(imgNum-1))))
				else
					self:Load(THEME:GetPathB("ScreenGalleryPage","overlay/_greylock"))
				end
			end;
			GainFocusCommand=cmd(); -- full color
			LoseFocusCommand=cmd(); -- desaturate
		};
		LoadActor("_selected")..{
			Name="Selected";
			InitCommand=cmd(x,8;y,4);
			BeginCommand=function(self)
				--self:visible(fakeSelected)
				self:visible(false)
			end;
			ShowCommand=cmd(visible,true);
			HideCommand=cmd(visible,false);
		};
		LoadFont("_gallery nums")..{
			Name="LabelNumber";
			InitCommand=cmd(x,-62;y,-44;halign,1;rotationz,-90;diffuse,color("#FFA5FF"));
			BeginCommand=function(self)
				self:settext(imageStart+(imgNum-1))
				self:playcommand(imgNum == 1 and "GainFocus" or "LoseFocus")
			end;
			GainFocusCommand=cmd(diffuse,color("#8C315B"));
			LoseFocusCommand=cmd(diffuse,color("#FFA5FF"));
			ChangedItemMessageCommand=function(self,param)
				if param.NewIndex == imgNum then
					self:playcommand("GainFocus")
				elseif param.OldIndex == imgNum then
					self:playcommand("LoseFocus")
				end
			end;
		};
		LoadActor("_new")..{
			Name="NewIcon";
			InitCommand=cmd(x,42;y,33;);
			BeginCommand=function(self)
				self:visible(showThumb)
			end;
		};
	};
end
local images = {}
for i=1,numImages do
	images[i] = MakeImageItem(i)
end

return Def.ActorFrame{
	Def.Actor{
		Name="Controller";
		MenuInputMessageCommand=function(self,param)
			-- handle movement, pressing start, select.
			if param.Input == "Start" then
				-- show image
			elseif param.Input == "Select" then
				-- toggle image for selection
			else
				-- directions
				prevIndex = selIndex
				if param.Input == "Up" then
					if selIndex < 5 then
						-- wrap to bottom row
					else
						-- subtract 4
						selIndex = selIndex - 4
					end
				elseif param.Input == "Down" then
					if selIndex > 8 then
						-- wrap to top row
					else
						-- add 4
						selIndex = selIndex + 4
					end
				elseif param.Input == "Left" then
					-- check for edge
					if selIndex == 1 or selIndex == 5 or selIndex == 9 then
						-- page left
					else
						selIndex = selIndex - 1
					end
				elseif param.Input == "Right" then
					-- check for edge
					if selIndex == 4 or selIndex == 8 or selIndex == 12 then
						-- page right
					else
						selIndex = selIndex + 1
					end
				end
				MESSAGEMAN:Broadcast("ChangedItem",{NewIndex=selIndex, OldIndex=prevIndex})
			end
		end;
		MenuUpP1MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_1, Input = "Up", }); end;
		MenuUpP2MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_2, Input = "Up", }); end;
		MenuDownP1MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_1, Input = "Down", }); end;
		MenuDownP2MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_2, Input = "Down", }); end;
		MenuLeftP1MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_1, Input = "Left", }); end;
		MenuLeftP2MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_2, Input = "Left", }); end;
		MenuRightP1MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_1, Input = "Right", }); end;
		MenuRightP2MessageCommand=function(self) MESSAGEMAN:Broadcast("MenuInput", { Player = PLAYER_2, Input = "Right", }); end;
		CodeMessageCommand=function(self,param)
			MESSAGEMAN:Broadcast("MenuInput", { Player = param.PlayerNumber, Input = param.Name, })
		end;
	};

	Def.ActorScroller{
		InitCommand=cmd(x,SCREEN_CENTER_X-400;y,SCREEN_CENTER_Y-137);
		children = images;
		SecondsPerItem=0;
		NumItemsToDraw=numImages*2;
		TransformFunction=function(self, offset, itemIndex, numItems)
			-- four items per line for three lines
			if itemIndex < 4 then
				-- row one
				self:x((itemIndex+1) * 160)
				self:y(0)
			elseif itemIndex >= 4 and itemIndex < 8 then
				-- row two
				self:x((itemIndex - 3) * 160)
				self:y(96*1)
			elseif itemIndex >= 8 then
				-- row three
				self:x((itemIndex - 7) * 160)
				self:y(96*2)
			end
		end
	};

	-- item description
	-- top line: #00FFE6; other lines: #FFFFFF
};